@@ -1,4 +1,4 @@
-# $Id: cmon.py 929 2014-06-13 02:50:38Z mwall $
+# $Id: cmon.py 930 2014-06-21 15:22:48Z mwall $
 # Copyright 2013 Matthew Wall
 """weewx module that records cpu, memory, disk, and network usage.
 
@@ -481,7 +481,7 @@ class ComputerMonitor(StdService):
                     m = self.DIGITS.search(line)
                     if m:
                         record['ups_charge'] = float(m.group())
-                elif line.startswith('OUTPUTV'):
+                elif line.startswith('OUTPUTV') or line.startswith('BATTV'):
                     m = self.DIGITS.search(line)
                     if m:
                         record['ups_voltage'] = float(m.group())
